==> kdlutils-1.1.tar.gz: kdlutils-1.1/setup.py <==
from distutils.core import setup
setup(
  name = 'kdlutils',         # How you named your package folder
  packages = ['kdlutils'],   # Chose the same as "name"
  version = '1.1',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'This library has several helper functions for deep learning',   # Give a short description about your library
  author = 'kaustubh sadekar',                   # Type in your name
  url = 'https://github.com/kaustubh-sadekar/githubActions',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/kaustubh-sadekar/githubActions/archive/v_1.1.tar.gz',    # I explain this later on
  keywords = ['Deep Learning', 'Helper functions'],   # Keywords that define your package best
  install_requires=[            # I get to this in a second
          'validators',
          'beautifulsoup4',
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
  ],
)

==> kdlutils-1.2.tar.gz: kdlutils-1.2/setup.py <==
from distutils.core import setup

with open("README.md", "r") as fh:
    long_description = fh.read()

setup(
  name = 'kdlutils',         # How you named your package folder
  packages = ['kdlutils'],   # Chose the same as "name"
  version = '1.2',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'This library has several helper functions for deep learning',
  long_description=long_description,
  long_description_content_type="text/markdown",
  author = 'kaustubh sadekar',                   # Type in your name
  url = 'https://github.com/kaustubh-sadekar/githubActions',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/kaustubh-sadekar/githubActions/archive/v_1.1.tar.gz',    # I explain this later on
  keywords = ['Deep Learning', 'Helper functions'],   # Keywords that define your package best
  install_requires=[            # I get to this in a second
          'validators',
          'beautifulsoup4',
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
  ],
)
